@@ -8,44 +8,47 @@
 #' @param labels a data frame of labels, one row for each element of res
 #' @keywords internal
 list_to_dataframe <- function(res, labels = NULL) {
-  res <- compact(res)
+  null <- vapply(res, is.null, logical(1))
+  res <- res[!null]
   if (length(res) == 0) return(data.frame())
 
+  if (!is.null(labels)) {
+    stopifnot(nrow(labels) == length(null))
+    labels <- labels[!null, , drop = FALSE]
+  }
+  if (is.null(labels) && !is.null(names(res))) {
+    labels <- data.frame(.id = names(res), stringsAsFactors = FALSE)
+  }
+
+  # Figure out how to turn elements into a data frame
   atomic <- unlist(lapply(res, is.atomic))
   df <- unlist(lapply(res, is.data.frame))
 
   if (all(atomic)) {
-    ulength <- unique(unlist(lapply(res, length)))
-    if (length(ulength) != 1) stop("Results do not have equal lengths")
+    nrow <- length(res)
+    ncol <- unique(unlist(lapply(res, length)))
+    if (length(ncol) != 1) stop("Results do not have equal lengths")
     
-    if (length(res) > 1) {
-      resdf <- as.data.frame(do.call("rbind", res), stringsAsFactors = FALSE)
-    } else {
-      resdf <- as.data.frame(res[[1]], stringsAsFactors = FALSE)
-      resdf <- t(resdf) # since the dimnames are switched
-    }
-    rows <- rep(1, length(res))
+    vec <- unname(do.call("c", res))
+    
+    resdf <- quickdf(unname(split(vec, rep(seq_len(ncol), nrow))))
+    names(resdf) <- make_names(res[[1]], "V")
+    
+    rows <- rep(ncol, length(nrow))
   } else if (all(df)) {
     resdf <- rbind.fill(res)
     rows <- unlist(lapply(res, NROW))
   } else {
     stop("Results must be all atomic, or all data frames")
   }
-
-  # If no labels supplied, use list names
-  if (is.null(labels) && !is.null(names(res))) {
-    labels <- data.frame(.id = names(res), stringsAsFactors = FALSE)
-  }
-
-  if (!is.null(labels) && nrow(labels) == length(res)) {
-    missing_names <- names(labels) == ""
-    names(labels)[missing_names] <- paste("X", seq_len(sum(missing_names)),
-       sep = "")
-    
-    cols <- setdiff(names(labels), names(resdf))
-    resdf <- cbind(labels[rep(1:nrow(labels), rows), cols, drop=FALSE], resdf)
-  }
   
-  unrowname(resdf)
-}
+  if(is.null(labels)) return(unrowname(resdf))
 
+  # Add labels to results
+  names(labels) <- make_names(labels, "X")
+  
+  cols <- setdiff(names(labels), names(resdf))
+  labels <- labels[rep(1:nrow(labels), rows), cols, drop = FALSE]
+  
+  unrowname(cbind(labels, resdf))
+}
